@@ -15,12 +15,10 @@ import warnings
 import csv
 warnings.filterwarnings("ignore", category=np.VisibleDeprecationWarning) 
 
-
-os.chdir('/User/RLNEK_tests/Module_2_test')
+cwd = os.getcwd()
+os.chdir(cwd)
 
 # %%input experimental system parameters
-
-parameters = []
 ##INPUT the experimental system parameters
 mu = float(input('Enter fluid viscosity (dyne-s/cm\u00b2): ')) * 1e-13
 a = float(input('Enter cell/sphere radius (\u03BCm): ')) * 1e6
@@ -29,7 +27,6 @@ L = float(input('Enter receptor-ligand bond length (nm): ')) * 1e3
 b = float(input('Enter flow chamber height (\u03BCm): ')) * 1e6
 b /= 2
 w = float(input('Enter flow chamber width (\u03BCm): ')) * 1e6
-parameters.append([mu, a, b, L, w, d])
 
 ##SET the experimental system parameters to reduce redundancy
 #a = 7.85 * 1e6 # cell radius (um)
@@ -42,8 +39,7 @@ parameters.append([mu, a, b, L, w, d])
 
 y = a+d #critical disance of cell/sphere from chamber floor
 
-CCD_FPS = float(input('Enter CCD FPS: '))
-stop_dist = input(u'Enter minimum displacement (enter for 0.5 \u03BCm): D_min (\u03BCm) = ')
+stop_dist = input(u'Enter maximum displacement (enter for 0.5 \u03BCm): D_max (\u03BCm) = ')
 if stop_dist == '':
     stop_dist = float(0.5)
 else:
@@ -79,7 +75,7 @@ N_T_vals = []
 t_min_vals = []
 
 while True:
-    run = str(input('Enter \"y\" to input data or \"n\" to execute: ')) 
+    run = str(input('Enter \"y\" to input data files or \"n\" to execute: ')) 
     
     if run.lower() == 'n':
         break
@@ -246,6 +242,9 @@ for m in range(len(track_data)):
             x_pos = spots_raw_data['POSITION_X']
             y_pos = spots_raw_data['POSITION_Y']
             frame = spots_raw_data['FRAME']
+            times = spots_raw_data['POSITION_T']
+            
+            CCD_FPS = 1 / (times[1] - times[0])
             
             for i in range(len(filtered_tracks_list)): 
                 for j in range(len(trackID)):
@@ -932,8 +931,8 @@ headers = ['Filename', 'm_r (sites/\u03BCm\u00b2)', 'm_l (sites/\u03BCm\u00b2)',
            'Q (\u03BCL/hr)', 'Force (pN)', 'koff (1/s)', 'koff SEM', 'Nb/NT', 
            'Nb/NT SEM', 'k+ (\u03BCm\u00b2/s)', 'k+* (\u03BCm\u00b2/s)']
 
-with open('RLNEK.csv', 'w', newline='') as myfile:
-    wr = csv.writer(myfile, quoting=csv.QUOTE_ALL)
+with open('RLNEK.csv', 'w', encoding='utf-32', newline='') as myfile:
+    wr = csv.writer(myfile, delimiter='\t', quoting=csv.QUOTE_ALL)
     wr.writerow(['Module 2'])
     wr.writerow(headers)
 
